--
-- BrookridgeMap
--
-- @author  Stefan Geiger
-- @date  06/08/12
--
-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

BrookridgeMap = {}

local BrookridgeMap_mt = Class(BrookridgeMap, Mission00);


function BrookridgeMap:new(baseDirectory, customMt)
    local mt = customMt;
    if mt == nil then
        mt = BrookridgeMap_mt;
    end;
    local self = BrookridgeMap:superClass():new(baseDirectory, mt);

--    self.playerStartX = 39;
--    self.playerStartY = 0.1;
--    self.playerStartZ = -330;
--    self.playerRotX = 0;
--    self.playerRotY = Utils.degToRad(90);

    return self;
end;

function BrookridgeMap:delete()
    BrookridgeMap:superClass().delete(self);
end;

function BrookridgeMap:load()
    self:startLoadingTask();

    self.environment = Environment:new(Utils.getFilename("$data/sky/sky_day_night.i3d", self.baseDirectory), true, 8, true, true);

    self.helpIconsBase = nil;
    self.collectableHorseshoesObject = nil;
    self.fieldDefinitionBase = nil;
    self.vehicleShopBase = nil;

    self:loadMap(Utils.getFilename("map/brookridge.i3d", self.baseDirectory), true, self.loadMap01Finished, self);
end;

function BrookridgeMap:loadMap01Finished(node, arguments)

    self:loadMapXMLFile(Utils.getFilename("brookridge.xml", self.baseDirectory));

    self.missionPDA:loadMap(Utils.getFilename("pda_map.png", self.baseDirectory), 2048, 2048);

    g_inGameMenu:setMapViewsMap(Utils.getFilename("pda_map.png", self.baseDirectory));

    local iconSize = self.missionPDA.pdaMapWidth / 15;

    -- ATMs
    self.missionPDA:createMapHotspot("Bank", Utils.getFilename("$dataS2/missions/hud_pda_spot_bank.png", self.baseDirectory), 23.5, -141, iconSize, iconSize * (4 / 3), false, false, false, 0, true);

    -- Vehicle Shop
    self.missionPDA:createMapHotspot("Shop", Utils.getFilename("$dataS2/missions/hud_pda_spot_shop.png", self.baseDirectory), 27, -95, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    
    -- Egg
    self.missionPDA:createMapHotspot("Egg", Utils.getFilename("huds/hud_pda_spot_egg.png", self.baseDirectory), 24.5, -221.5, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    
    -- Wool
    self.missionPDA:createMapHotspot("Wool", Utils.getFilename("huds/hud_pda_spot_wool.png", self.baseDirectory), 41, -224.5, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    
    -- Liquid manure
    self.missionPDA:createMapHotspot("Manure", Utils.getFilename("huds/hud_pda_spot_manure.png", self.baseDirectory), 32.5, -343.5, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("Manure", Utils.getFilename("huds/hud_pda_spot_manure.png", self.baseDirectory), -142.5, 140.5, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    
    -- Water
    self.missionPDA:createMapHotspot("Water", Utils.getFilename("huds/hud_pda_spot_water.png", self.baseDirectory), -193.5, 215, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    
    -- Bale
    self.missionPDA:createMapHotspot("Bale", Utils.getFilename("huds/hud_pda_spot_bale.png", self.baseDirectory), -246, 204, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    
    -- farm silos
    self.missionPDA:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/missions/hud_pda_spot_tipPlace.png", self.baseDirectory), -195, 90, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/missions/hud_pda_spot_tipPlace.png", self.baseDirectory), -154, 213, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/missions/hud_pda_spot_tipPlace.png", self.baseDirectory), -195, 150, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
        
    -- bga
    self.missionPDA:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/missions/hud_pda_spot_tipPlace.png", self.baseDirectory), 30, -300, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/missions/hud_pda_spot_tipPlace.png", self.baseDirectory), 46.5, -380, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    
    -- livestock
    self.missionPDA:createMapHotspot("Cows", Utils.getFilename("$dataS2/missions/hud_pda_spot_cows.png", self.baseDirectory), -118, 127, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("Sheep", Utils.getFilename("$dataS2/missions/hud_pda_spot_sheep.png", self.baseDirectory), -102, 168, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("Chickens", Utils.getFilename("$dataS2/missions/hud_pda_spot_chickens.png", self.baseDirectory), -100, 200, iconSize, iconSize * (4 / 3), false, false, false, 0, true);

    BrookridgeMap:superClass().load(self);

    if not self.missionDynamicInfo.isMultiplayer then
        self:updateFoundHorseshoes();
        self:updateFoundHelpIcons();
        self:updateMeteoriteCrash();
        self:updateRainbow();
    else
        self:removeAllHorseshoes();
        self:removeAllHelpIcons();
    end;

    if g_isGamescomVersion then
        self:playerOwnsAllFields();
    end;

    self:finishLoadingTask();
end;

function BrookridgeMap:onStartMission()
    BrookridgeMap:superClass().onStartMission(self);
end;

function BrookridgeMap:mouseEvent(posX, posY, isDown, isUp, button)
    BrookridgeMap:superClass().mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function BrookridgeMap:keyEvent(unicode, sym, modifier, isDown)
    BrookridgeMap:superClass().keyEvent(self, unicode, sym, modifier, isDown);
end;

function BrookridgeMap:update(dt)
    BrookridgeMap:superClass().update(self, dt);
end;

function BrookridgeMap:draw()
    BrookridgeMap:superClass().draw(self);
end;